pub(crate) const PTR_SIZE: usize = 8;
pub(crate) const MAYBE_PTR_SIZE: usize = 8;
pub(crate) const LIST_SIZE: usize = 24;
pub(crate) const STRING_PTR_SIZE: usize = 16;
pub(crate) const MAYBE_STRING_PTR_SIZE: usize = 16;
pub(crate) const SHARED_BYTE_LIST_SIZE: usize = 16;
pub(crate) const BYTES_SIZE: usize = 24;
pub(crate) const TOKEN_SIZE: usize = 56;
pub(crate) const ERROR_LEVEL_SIZE: usize = 4;
pub(crate) const LOC_SIZE: usize = 16;
pub(crate) const MAYBE_LOC_SIZE: usize = 24;
pub(crate) const SOURCE_LINE_SIZE: usize = 24;
pub(crate) const COMMENT_TYPE_SIZE: usize = 4;
pub(crate) const COMMENT_SIZE: usize = 24;
pub(crate) const MAGIC_COMMENT_KIND_SIZE: usize = 4;
pub(crate) const MAGIC_COMMENT_SIZE: usize = 40;
pub(crate) const DIAGNOSTIC_MESSAGE_SIZE: usize = 40;
pub(crate) const NODE_ALIAS_SIZE: usize = 48;
pub(crate) const NODE_AND_SIZE: usize = 48;
pub(crate) const NODE_AND_ASGN_SIZE: usize = 48;
pub(crate) const NODE_ARG_SIZE: usize = 32;
pub(crate) const NODE_ARGS_SIZE: usize = 88;
pub(crate) const NODE_ARRAY_SIZE: usize = 88;
pub(crate) const NODE_ARRAY_PATTERN_SIZE: usize = 88;
pub(crate) const NODE_ARRAY_PATTERN_WITH_TAIL_SIZE: usize = 88;
pub(crate) const NODE_BACK_REF_SIZE: usize = 32;
pub(crate) const NODE_BEGIN_SIZE: usize = 88;
pub(crate) const NODE_BLOCK_SIZE: usize = 72;
pub(crate) const NODE_BLOCKARG_SIZE: usize = 64;
pub(crate) const NODE_BLOCK_PASS_SIZE: usize = 40;
pub(crate) const NODE_BREAK_SIZE: usize = 56;
pub(crate) const NODE_CASE_SIZE: usize = 112;
pub(crate) const NODE_CASE_MATCH_SIZE: usize = 112;
pub(crate) const NODE_CASGN_SIZE: usize = 112;
pub(crate) const NODE_CBASE_SIZE: usize = 16;
pub(crate) const NODE_CLASS_SIZE: usize = 96;
pub(crate) const NODE_COMPLEX_SIZE: usize = 56;
pub(crate) const NODE_CONST_SIZE: usize = 80;
pub(crate) const NODE_CONST_PATTERN_SIZE: usize = 64;
pub(crate) const NODE_C_SEND_SIZE: usize = 176;
pub(crate) const NODE_CVAR_SIZE: usize = 32;
pub(crate) const NODE_CVASGN_SIZE: usize = 80;
pub(crate) const NODE_DEF_SIZE: usize = 128;
pub(crate) const NODE_DEFINED_SIZE: usize = 88;
pub(crate) const NODE_DEFS_SIZE: usize = 152;
pub(crate) const NODE_DSTR_SIZE: usize = 88;
pub(crate) const NODE_DSYM_SIZE: usize = 88;
pub(crate) const NODE_E_FLIP_FLOP_SIZE: usize = 48;
pub(crate) const NODE_EMPTY_ELSE_SIZE: usize = 16;
pub(crate) const NODE_ENCODING_SIZE: usize = 16;
pub(crate) const NODE_ENSURE_SIZE: usize = 48;
pub(crate) const NODE_ERANGE_SIZE: usize = 48;
pub(crate) const NODE_FALSE_SIZE: usize = 16;
pub(crate) const NODE_FILE_SIZE: usize = 16;
pub(crate) const NODE_FIND_PATTERN_SIZE: usize = 88;
pub(crate) const NODE_FLOAT_SIZE: usize = 56;
pub(crate) const NODE_FOR_SIZE: usize = 104;
pub(crate) const NODE_FORWARD_ARG_SIZE: usize = 16;
pub(crate) const NODE_FORWARDED_ARGS_SIZE: usize = 16;
pub(crate) const NODE_GVAR_SIZE: usize = 32;
pub(crate) const NODE_GVASGN_SIZE: usize = 80;
pub(crate) const NODE_HASH_SIZE: usize = 88;
pub(crate) const NODE_HASH_PATTERN_SIZE: usize = 88;
pub(crate) const NODE_HEREDOC_SIZE: usize = 72;
pub(crate) const NODE_IF_SIZE: usize = 120;
pub(crate) const NODE_IF_GUARD_SIZE: usize = 40;
pub(crate) const NODE_I_FLIP_FLOP_SIZE: usize = 48;
pub(crate) const NODE_IF_MOD_SIZE: usize = 56;
pub(crate) const NODE_IF_TERNARY_SIZE: usize = 72;
pub(crate) const NODE_INDEX_SIZE: usize = 80;
pub(crate) const NODE_INDEX_ASGN_SIZE: usize = 112;
pub(crate) const NODE_IN_PATTERN_SIZE: usize = 72;
pub(crate) const NODE_INT_SIZE: usize = 56;
pub(crate) const NODE_IRANGE_SIZE: usize = 48;
pub(crate) const NODE_IVAR_SIZE: usize = 32;
pub(crate) const NODE_IVASGN_SIZE: usize = 80;
pub(crate) const NODE_KWARG_SIZE: usize = 48;
pub(crate) const NODE_KWARGS_SIZE: usize = 40;
pub(crate) const NODE_KW_BEGIN_SIZE: usize = 88;
pub(crate) const NODE_KWNILARG_SIZE: usize = 32;
pub(crate) const NODE_KWOPTARG_SIZE: usize = 56;
pub(crate) const NODE_KWRESTARG_SIZE: usize = 72;
pub(crate) const NODE_KWSPLAT_SIZE: usize = 40;
pub(crate) const NODE_LAMBDA_SIZE: usize = 16;
pub(crate) const NODE_LINE_SIZE: usize = 16;
pub(crate) const NODE_LVAR_SIZE: usize = 32;
pub(crate) const NODE_LVASGN_SIZE: usize = 80;
pub(crate) const NODE_MASGN_SIZE: usize = 48;
pub(crate) const NODE_MATCH_ALT_SIZE: usize = 48;
pub(crate) const NODE_MATCH_AS_SIZE: usize = 48;
pub(crate) const NODE_MATCH_CURRENT_LINE_SIZE: usize = 24;
pub(crate) const NODE_MATCH_NIL_PATTERN_SIZE: usize = 48;
pub(crate) const NODE_MATCH_PATTERN_SIZE: usize = 48;
pub(crate) const NODE_MATCH_PATTERN_P_SIZE: usize = 48;
pub(crate) const NODE_MATCH_REST_SIZE: usize = 40;
pub(crate) const NODE_MATCH_VAR_SIZE: usize = 48;
pub(crate) const NODE_MATCH_WITH_LVASGN_SIZE: usize = 48;
pub(crate) const NODE_MLHS_SIZE: usize = 88;
pub(crate) const NODE_MODULE_SIZE: usize = 64;
pub(crate) const NODE_NEXT_SIZE: usize = 56;
pub(crate) const NODE_NIL_SIZE: usize = 16;
pub(crate) const NODE_NTH_REF_SIZE: usize = 32;
pub(crate) const NODE_NUMBLOCK_SIZE: usize = 72;
pub(crate) const NODE_OP_ASGN_SIZE: usize = 64;
pub(crate) const NODE_OPTARG_SIZE: usize = 72;
pub(crate) const NODE_OR_SIZE: usize = 48;
pub(crate) const NODE_OR_ASGN_SIZE: usize = 48;
pub(crate) const NODE_PAIR_SIZE: usize = 48;
pub(crate) const NODE_PIN_SIZE: usize = 40;
pub(crate) const NODE_POSTEXE_SIZE: usize = 72;
pub(crate) const NODE_PREEXE_SIZE: usize = 72;
pub(crate) const NODE_PROCARG0_SIZE: usize = 88;
pub(crate) const NODE_RATIONAL_SIZE: usize = 56;
pub(crate) const NODE_REDO_SIZE: usize = 16;
pub(crate) const NODE_REGEXP_SIZE: usize = 80;
pub(crate) const NODE_REG_OPT_SIZE: usize = 32;
pub(crate) const NODE_RESCUE_SIZE: usize = 80;
pub(crate) const NODE_RESCUE_BODY_SIZE: usize = 104;
pub(crate) const NODE_RESTARG_SIZE: usize = 72;
pub(crate) const NODE_RETRY_SIZE: usize = 16;
pub(crate) const NODE_RETURN_SIZE: usize = 56;
pub(crate) const NODE_S_CLASS_SIZE: usize = 80;
pub(crate) const NODE_SELF__SIZE: usize = 16;
pub(crate) const NODE_SEND_SIZE: usize = 184;
pub(crate) const NODE_SHADOWARG_SIZE: usize = 32;
pub(crate) const NODE_SPLAT_SIZE: usize = 40;
pub(crate) const NODE_STR_SIZE: usize = 88;
pub(crate) const NODE_SUPER_SIZE: usize = 104;
pub(crate) const NODE_SYM_SIZE: usize = 88;
pub(crate) const NODE_TRUE_SIZE: usize = 16;
pub(crate) const NODE_UNDEF_SIZE: usize = 56;
pub(crate) const NODE_UNLESS_GUARD_SIZE: usize = 40;
pub(crate) const NODE_UNTIL_SIZE: usize = 96;
pub(crate) const NODE_UNTIL_POST_SIZE: usize = 48;
pub(crate) const NODE_WHEN_SIZE: usize = 80;
pub(crate) const NODE_WHILE_SIZE: usize = 96;
pub(crate) const NODE_WHILE_POST_SIZE: usize = 48;
pub(crate) const NODE_X_HEREDOC_SIZE: usize = 72;
pub(crate) const NODE_XSTR_SIZE: usize = 72;
pub(crate) const NODE_YIELD_SIZE: usize = 104;
pub(crate) const NODE_Z_SUPER_SIZE: usize = 16;
pub(crate) const MESSAGE_FRACTION_AFTER_NUMERIC_SIZE: usize = 0;
pub(crate) const MESSAGE_NO_DIGITS_AFTER_DOT_SIZE: usize = 0;
pub(crate) const MESSAGE_UNKNOWN_TYPE_OF_PERCENT_STRING_SIZE: usize = 0;
pub(crate) const MESSAGE_NUMERIC_LITERAL_WITHOUT_DIGITS_SIZE: usize = 0;
pub(crate) const MESSAGE_UNTERMINATED_LIST_SIZE: usize = 0;
pub(crate) const MESSAGE_UNTERMINATED_REGEXP_SIZE: usize = 0;
pub(crate) const MESSAGE_UNTERMINATED_STRING_SIZE: usize = 0;
pub(crate) const MESSAGE_UNTERMINATED_QUOTED_STRING_SIZE: usize = 0;
pub(crate) const MESSAGE_INVALID_UNICODE_ESCAPE_SIZE: usize = 0;
pub(crate) const MESSAGE_TOO_LARGE_UNICODE_CODEPOINT_SIZE: usize = 0;
pub(crate) const MESSAGE_INVALID_UNICODE_CODEPOINT_SIZE: usize = 0;
pub(crate) const MESSAGE_MULTIPLE_CODEPOINT_AT_SINGLE_CHAR_SIZE: usize = 0;
pub(crate) const MESSAGE_INVALID_ESCAPE_CHARACTER_SIZE: usize = 0;
pub(crate) const MESSAGE_INVALID_HEX_ESCAPE_SIZE: usize = 0;
pub(crate) const MESSAGE_UNTERMINATED_HEREDOC_SIZE: usize = 16;
pub(crate) const MESSAGE_UNTERMINATED_HEREDOC_ID_SIZE: usize = 0;
pub(crate) const MESSAGE_SLASH_R_AT_MIDDLE_OF_LINE_SIZE: usize = 0;
pub(crate) const MESSAGE_D_STAR_INTERPRETED_AS_ARG_PREFIX_SIZE: usize = 0;
pub(crate) const MESSAGE_STAR_INTERPRETED_AS_ARG_PREFIX_SIZE: usize = 0;
pub(crate) const MESSAGE_AMPERSAND_INTERPRETED_AS_ARG_PREFIX_SIZE: usize = 0;
pub(crate) const MESSAGE_TRIPLE_DOT_AT_EOL_SIZE: usize = 0;
pub(crate) const MESSAGE_PARENTHESES_ITERPRETED_AS_ARGLIST_SIZE: usize = 0;
pub(crate) const MESSAGE_AMBIGUOUS_FIRST_ARGUMENT_SIZE: usize = 1;
pub(crate) const MESSAGE_AMBIGUOUS_OPERATOR_SIZE: usize = 32;
pub(crate) const MESSAGE_INVALID_CHARACTER_SYNTAX_SIZE: usize = 16;
pub(crate) const MESSAGE_INVALID_OCTAL_DIGIT_SIZE: usize = 0;
pub(crate) const MESSAGE_TRAILING_CHAR_IN_NUMBER_SIZE: usize = 1;
pub(crate) const MESSAGE_EMBEDDED_DOCUMENT_MEETS_EOF_SIZE: usize = 0;
pub(crate) const MESSAGE_INVALID_CHAR_SIZE: usize = 1;
pub(crate) const MESSAGE_INCOMPLETE_CHARACTER_SYNTAX_SIZE: usize = 0;
pub(crate) const MESSAGE_GVAR_WITHOUT_ID_SIZE: usize = 0;
pub(crate) const MESSAGE_INVALID_GVAR_NAME_SIZE: usize = 1;
pub(crate) const MESSAGE_IVAR_WITHOUT_ID_SIZE: usize = 0;
pub(crate) const MESSAGE_INVALID_IVAR_NAME_SIZE: usize = 1;
pub(crate) const MESSAGE_CVAR_WITHOUT_ID_SIZE: usize = 0;
pub(crate) const MESSAGE_INVALID_CVAR_NAME_SIZE: usize = 1;
pub(crate) const MESSAGE_UNKNOWN_REGEX_OPTIONS_SIZE: usize = 16;
pub(crate) const MESSAGE_UNTERMINATED_UNICODE_ESCAPE_SIZE: usize = 0;
pub(crate) const MESSAGE_ENCODING_ERROR_SIZE: usize = 16;
pub(crate) const MESSAGE_INVALID_MULTIBYTE_CHAR_SIZE: usize = 0;
pub(crate) const MESSAGE_AMBIGUOUS_TERNARY_OPERATOR_SIZE: usize = 16;
pub(crate) const MESSAGE_AMBIGUOUS_REGEXP_SIZE: usize = 0;
pub(crate) const MESSAGE_ELSE_WITHOUT_RESCUE_SIZE: usize = 0;
pub(crate) const MESSAGE_BEGIN_NOT_AT_TOP_LEVEL_SIZE: usize = 0;
pub(crate) const MESSAGE_ALIAS_NTH_REF_SIZE: usize = 0;
pub(crate) const MESSAGE_CSEND_INSIDE_MASGN_SIZE: usize = 0;
pub(crate) const MESSAGE_CLASS_OR_MODULE_NAME_MUST_BE_CONSTANT_SIZE: usize = 0;
pub(crate) const MESSAGE_ENDLESS_SETTER_DEFINITION_SIZE: usize = 0;
pub(crate) const MESSAGE_UNEXPECTED_TOKEN_SIZE: usize = 16;
pub(crate) const MESSAGE_CLASS_DEFINITION_IN_METHOD_BODY_SIZE: usize = 0;
pub(crate) const MESSAGE_MODULE_DEFINITION_IN_METHOD_BODY_SIZE: usize = 0;
pub(crate) const MESSAGE_INVALID_RETURN_IN_CLASS_OR_MODULE_BODY_SIZE: usize = 0;
pub(crate) const MESSAGE_CONST_ARGUMENT_SIZE: usize = 0;
pub(crate) const MESSAGE_IVAR_ARGUMENT_SIZE: usize = 0;
pub(crate) const MESSAGE_GVAR_ARGUMENT_SIZE: usize = 0;
pub(crate) const MESSAGE_CVAR_ARGUMENT_SIZE: usize = 0;
pub(crate) const MESSAGE_NO_SUCH_LOCAL_VARIABLE_SIZE: usize = 16;
pub(crate) const MESSAGE_ORDINARY_PARAM_DEFINED_SIZE: usize = 0;
pub(crate) const MESSAGE_NUMPARAM_USED_SIZE: usize = 0;
pub(crate) const MESSAGE_TOK_AT_EOL_WITHOUT_EXPRESSION_SIZE: usize = 16;
pub(crate) const MESSAGE_END_IN_METHOD_SIZE: usize = 0;
pub(crate) const MESSAGE_COMPARISON_AFTER_COMPARISON_SIZE: usize = 16;
pub(crate) const MESSAGE_CIRCULAR_ARGUMENT_REFERENCE_SIZE: usize = 16;
pub(crate) const MESSAGE_DYNAMIC_CONSTANT_ASSIGNMENT_SIZE: usize = 0;
pub(crate) const MESSAGE_CANT_ASSIGN_TO_SELF_SIZE: usize = 0;
pub(crate) const MESSAGE_CANT_ASSIGN_TO_NIL_SIZE: usize = 0;
pub(crate) const MESSAGE_CANT_ASSIGN_TO_TRUE_SIZE: usize = 0;
pub(crate) const MESSAGE_CANT_ASSIGN_TO_FALSE_SIZE: usize = 0;
pub(crate) const MESSAGE_CANT_ASSIGN_TO_FILE_SIZE: usize = 0;
pub(crate) const MESSAGE_CANT_ASSIGN_TO_LINE_SIZE: usize = 0;
pub(crate) const MESSAGE_CANT_ASSIGN_TO_ENCODING_SIZE: usize = 0;
pub(crate) const MESSAGE_CANT_ASSIGN_TO_NUMPARAM_SIZE: usize = 16;
pub(crate) const MESSAGE_CANT_SET_VARIABLE_SIZE: usize = 16;
pub(crate) const MESSAGE_BLOCK_GIVEN_TO_YIELD_SIZE: usize = 0;
pub(crate) const MESSAGE_BLOCK_AND_BLOCK_ARG_GIVEN_SIZE: usize = 0;
pub(crate) const MESSAGE_SYMBOL_LITERAL_WITH_INTERPOLATION_SIZE: usize = 0;
pub(crate) const MESSAGE_RESERVED_FOR_NUMPARAM_SIZE: usize = 16;
pub(crate) const MESSAGE_KEY_MUST_BE_VALID_AS_LOCAL_VARIABLE_SIZE: usize = 0;
pub(crate) const MESSAGE_DUPLICATE_VARIABLE_NAME_SIZE: usize = 0;
pub(crate) const MESSAGE_DUPLICATE_KEY_NAME_SIZE: usize = 0;
pub(crate) const MESSAGE_SINGLETON_LITERAL_SIZE: usize = 0;
pub(crate) const MESSAGE_NTH_REF_IS_TOO_BIG_SIZE: usize = 16;
pub(crate) const MESSAGE_DUPLICATED_ARGUMENT_NAME_SIZE: usize = 0;
pub(crate) const MESSAGE_REGEX_ERROR_SIZE: usize = 16;
pub(crate) const MESSAGE_INVALID_SYMBOL_SIZE: usize = 16;
pub(crate) const MESSAGE_VOID_VALUE_EXPRESSION_SIZE: usize = 0;
pub(crate) const DIAGNOSTIC_SIZE: usize = 64;
pub(crate) const NODE_SIZE: usize = 192;
pub(crate) const INPUT_ERROR_SIZE: usize = 24;
pub(crate) const DECODER_RESULT_SIZE: usize = 32;
pub(crate) const DECODER_SIZE: usize = 8;
pub(crate) const REWRITE_ACTION_SIZE: usize = 4;
pub(crate) const LEX_STATE_ACTION_SIZE: usize = 8;
pub(crate) const TOKEN_REWRITER_RESULT_SIZE: usize = 24;
pub(crate) const TOKEN_REWRITER_SIZE: usize = 16;
pub(crate) const MAYBE_DECODER_SIZE: usize = 16;
pub(crate) const MAYBE_TOKEN_REWRITER_SIZE: usize = 24;
pub(crate) const PARSER_OPTIONS_SIZE: usize = 64;
pub(crate) const DECODED_INPUT_SIZE: usize = 64;
pub(crate) const PARSER_RESULT_SIZE: usize = 168;